@@ -2,7 +2,10 @@ use anyhow::{format_err, Result};
 use full_moon::visitors::VisitorMut;
 use serde::Deserialize;
 
+#[macro_use]
+mod context;
 mod formatters;
+mod shape;
 
 /// The type of indents to use when indenting
 #[derive(Debug, Copy, Clone, Deserialize)]
